@@ -3,9 +3,11 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
+from lilt.api.comments_api import CommentsApi
 from lilt.api.connectors_api import ConnectorsApi
 from lilt.api.documents_api import DocumentsApi
 from lilt.api.files_api import FilesApi
+from lilt.api.jobs_api import JobsApi
 from lilt.api.languages_api import LanguagesApi
 from lilt.api.lexicon_api import LexiconApi
 from lilt.api.memories_api import MemoriesApi
@@ -13,4 +15,5 @@ from lilt.api.projects_api import ProjectsApi
 from lilt.api.qa_api import QAApi
 from lilt.api.root_api import RootApi
 from lilt.api.segments_api import SegmentsApi
+from lilt.api.settings_api import SettingsApi
 from lilt.api.translate_api import TranslateApi
